package com.uas.cloud.mall.service.api;

import com.uas.cloud.mall.service.facade.ContentFacade;
import com.uas.cloud.mall.service.domain.Content;
import com.uas.cloud.mall.service.domain.Module;
import com.uas.cloud.mall.service.service.ContentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController
@RequestMapping("/mall-cms-service")
public class ContentController {

	private final ContentService contentService;

	private final ContentFacade contentFacade;

	@Autowired
	public ContentController(ContentService contentService, ContentFacade contentFacade) {
		this.contentService = contentService;
		this.contentFacade = contentFacade;
	}

	/**
	 * 新增或修改内容信息
	 *
	 * @param content	待持久化的内容
	 */
	@RequestMapping(value = "/contents", method = RequestMethod.POST)
	public Content saveContent(@RequestBody Content content) {
		return contentService.saveContent(content);
	}

	/**
	 * 根据内容ID删除内容信息
	 *
	 * @param id	内容主键ID
	 */
	@RequestMapping(value = "/contents/{id}", method = RequestMethod.DELETE)
	public Content deleteContent(@PathVariable("id") String id) {
		return contentService.deleteContent(id);
	}

	/**
	 * 根据模块名称获取内容列表
	 *
	 * @param moduleName	模板名称
	 */
	@RequestMapping(value = "/contents", method = RequestMethod.GET)
	public List<Content> findByModuleName(String moduleName) {
		return contentService.findByModuleName(moduleName);
	}

	/**
	 * 获取当前URI中所有模块信息
	 *
	 * @param path	当前URI路径
	 */
	@RequestMapping(value = "/modules", method = RequestMethod.GET)
	public List<Module> findModulesByPath(@RequestParam("path") String path, HttpServletRequest request) {
		String realPath = request.getSession().getServletContext().getRealPath("/");
		return contentFacade.findModulesByPath(path, realPath);
	}

}
