package com.uas.cloud.mall.service.api;

import com.uas.cloud.mall.service.domain.StoreCms;
import com.uas.cloud.mall.service.service.StoreCmsService;
import com.uas.cloud.mall.service.statusAndType.PageForType;
import com.uas.cloud.mall.service.statusAndType.StoreCmsType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(value = "/mall-cms-service")
public class StoreCmsController {

    private final StoreCmsService storeCmsService;

    @Autowired
    public StoreCmsController(StoreCmsService storeCmsService) {
        this.storeCmsService = storeCmsService;
    }

    /**
     * 根据以下两个属性，获取店铺的信息
     * @param useFor
     * @param cmsType
     * @return  List<StoreCms>
     */
    @RequestMapping(value = "/storeCms", method = RequestMethod.GET, produces = "application/json")
    public List<StoreCms> getStoreCmsByUseForAndCmsType(@RequestParam("useFor") String useFor, @RequestParam("cmsType") String cmsType) {
        return storeCmsService.getStoreCmsByUseForAndCmsType(useFor, cmsType);
    }

    /**
     * 批量添加某一页面的某种内容
     *
     * @param storeCmsList      商城店铺相关内容列表
     * @param useFor            内容呈现页面
     * @param cmsType           内容类型
     */
    @RequestMapping(value = "/storeCms/batch", method = RequestMethod.POST, produces = "application/json")
    public List<StoreCms> batchAddOneTypeStoreCms(@RequestParam("useFor") PageForType useFor, @RequestParam("cmsType") StoreCmsType cmsType,
              @RequestBody List<StoreCms> storeCmsList) {
        return storeCmsService.batchAddOneTypeStoreCms(storeCmsList, useFor, cmsType);
    }

    /**
     * 添加一条某一页面的某种内容
     *
     * @param storeCms      商城店铺相关内容
     * @param useFor        内容呈现页面
     * @param cmsType       内容类型
     */
    @RequestMapping(value = "/storeCms", method = RequestMethod.POST, produces = "application/json")
    public ResponseEntity<Map<String, Boolean>> addOneTypeStoreCms(@RequestParam("useFor") PageForType useFor, @RequestParam("cmsType") StoreCmsType cmsType,
           @RequestBody StoreCms storeCms) {
        storeCms = storeCmsService.addOneTypeStoreCms(storeCms, useFor, cmsType);
        Map<String, Boolean> map = new HashMap<>();
        map.put("success", false);
        if (storeCms != null && StringUtils.hasText(storeCms.getId())) {
            map.replace("success", true);
        }
        return new ResponseEntity<>(map, HttpStatus.CREATED);
    }
}
