package com.uas.cloud.mall.service.facade.impl;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.uas.cloud.mall.service.facade.ContentFacade;
import com.uas.cloud.mall.service.domain.Content;
import com.uas.cloud.mall.service.domain.Module;
import com.uas.cloud.mall.service.service.ContentService;
import com.uas.cloud.mall.service.util.CommonUtils;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.io.IOException;
import java.util.Collections;
import java.util.List;

@Service
public class ContentFacadeImpl implements ContentFacade {

	private final ContentService contentService;

	private static final String PROFILE_LOCATION = "resources/profile/module-info.json";

	@Autowired
	public ContentFacadeImpl(ContentService contentService) {
		this.contentService = contentService;
	}

	@Override
	public List<Module> findModulesByPath(String path, String realPath) {
		if (StringUtils.isEmpty(realPath) || StringUtils.isEmpty(path)) {
			return Collections.emptyList();
		}
		JSONObject profile = CommonUtils.obtainProfile(realPath, PROFILE_LOCATION);
		if (profile == null) {
			return Collections.emptyList();
		}
		try {
			String modulesJson = profile.getString(path);
			if (StringUtils.isEmpty(modulesJson)) {
				return Collections.emptyList();
			}
			ObjectMapper mapper = new ObjectMapper();
			List<Module> modules = mapper.readValue(modulesJson, new TypeReference<List<Module>>() {});
			if (CollectionUtils.isEmpty(modules)) {
				return Collections.emptyList();
			}
			for (Module module : modules) {
				List<Content> contents = contentService.findByModuleName(module.getName());
				if (!CollectionUtils.isEmpty(contents)) {
					module.setContents(contents);
				}
			}
			return modules;
		} catch (JSONException | IOException e) {
			e.printStackTrace();
			return Collections.emptyList();
		}
	}
}
