package com.uas.cloud.mall.service.service.impl;

import com.uas.cloud.mall.service.domain.HotComponent;
import com.uas.cloud.mall.service.repository.HotComponentRepository;
import com.uas.cloud.mall.service.service.HotComponentService;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.Collections;
import java.util.List;

/**
 * Created by yujia on 2017/3/13.
 */
@Service
public class HotComponentServiceImpl implements HotComponentService {

    private final HotComponentRepository hotComponentRepository;

    public HotComponentServiceImpl(HotComponentRepository hotComponentRepository) {
        this.hotComponentRepository = hotComponentRepository;
    }

    /**
     * 保存hotComponent
     *
     * @param hotComponent
     * @return
     */
    @Override
    public HotComponent save(HotComponent hotComponent) {
        return hotComponentRepository.save(hotComponent);
    }

    /**
     * 删除指定的ID 的hotComponent
     *
     * @param id
     */
    @Override
    public void delete(String id) {
        if(StringUtils.isEmpty(id)) {
            return ;
        }
        hotComponentRepository.delete(id);
    }

    /**
     * 更新hotComponent
     *
     * @param hotComponent
     */
    @Override
    public HotComponent update(HotComponent hotComponent) {
        //// TODO: 2017/3/13
        return null;
    }

    /**
     * 获取指定的HotComponent
     *
     * @param id
     * @return
     */
    @Override
    public HotComponent getHotComponent(String id) {
        if(StringUtils.isEmpty(id)) {
            return null;
        }
        return hotComponentRepository.findOne(id);
    }

    /**
     * 根据用户的用途，来获取list HotComponent
     * 如果两个参数的任意一个为空，返回空的list
     * @param useFor
     * @param pageFor
     * @return List<HotComponent>
     */
    @Override
    public List<HotComponent> getHotComponentForPageAndUseFor(String useFor, String pageFor) {
        if(StringUtils.isEmpty(useFor) || StringUtils.isEmpty(pageFor)) {
            return Collections.emptyList();
        }
        return hotComponentRepository.findByUseForAndPageFor(useFor, pageFor);
    }

    /**
     * 批量保存 lsit  hotComponent
     *
     * @param hotComponents
     * @return
     */
    @Override
    public List<HotComponent> save(List<HotComponent> hotComponents) {
        return hotComponentRepository.save(hotComponents);
    }
}
