package com.uas.cloud.mall.service.service.impl;

import com.uas.cloud.mall.service.domain.StoreCms;
import com.uas.cloud.mall.service.repository.StoreCmsRepository;
import com.uas.cloud.mall.service.service.StoreCmsService;
import com.uas.cloud.mall.service.statusAndType.PageForType;
import com.uas.cloud.mall.service.statusAndType.StoreCmsType;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.Collections;
import java.util.List;

@Service
public class StoreCmsServiceImpl implements StoreCmsService {

	private final StoreCmsRepository storeCmsRepository;

	public StoreCmsServiceImpl(StoreCmsRepository storeCmsRepository) {
		this.storeCmsRepository = storeCmsRepository;
	}

	/**
	 * 更新某一类型的店铺内容
	 *
	 * @param storeCmses
	 * @return
	 */
	@Override
	public List<StoreCms> updateStoreCmss(List<StoreCms> storeCmses) {
		return storeCmsRepository.save(storeCmses);
	}

	/**
	 * 更新指定的StoreCms的类型
	 *
	 * @param storeCms
	 * @return StoreCms
	 */
	@Override
	public StoreCms updateStoreCm(StoreCms storeCms) {
		//TODO 不想这么直接更新
		return null;
	}

	/**
	 * 获取某一用途、某一类型的StoreCms
	 *
	 * @param useFor  指用于那个界面，
	 * @param cmsType 什么类型的店铺
	 * @return List<StoreCms>
	 */
	@Override
	public List<StoreCms> getStoreCmsByUseForAndCmsType(String useFor, String cmsType) {
		if(StringUtils.isEmpty(useFor) || StringUtils.isEmpty(cmsType)) {
			Collections.emptyList();
		}
		return storeCmsRepository.findByUseForAndCmsType(useFor, cmsType);
	}

	@Override
	public List<StoreCms> batchAddOneTypeStoreCms(List<StoreCms> storeCmsList, PageForType useFor, StoreCmsType cmsType) {
		if (CollectionUtils.isEmpty(storeCmsList) || useFor == null || cmsType == null) {
			return Collections.emptyList();
		}
		int num = 0;
		for (StoreCms cms : storeCmsList) {
			if (!useFor.name().equals(cms.getUseFor()) || !cmsType.name().equals(cms.getCmsType()) || StringUtils.isEmpty(cms.getStoreid())) {
				return Collections.emptyList();
			} else if (cms.getNum() != 0){
				num ++;
			}
		}
		if (num < storeCmsList.size()) {
			num = 0;
			for (StoreCms cms : storeCmsList) {
				cms.setNum(++ num);
			}
		}
		return storeCmsRepository.save(storeCmsList);
	}

	@Override
	public StoreCms addOneTypeStoreCms(StoreCms storeCms, PageForType useFor, StoreCmsType cmsType) {
		if (useFor == null || cmsType == null) {
			return null;
		}
		if (!validateStoreCms(storeCms)) {
			return null;
		}
		if (!useFor.name().equals(storeCms.getUseFor()) || !cmsType.name().equals(storeCms.getCmsType())) {
			return null;
		}
		List<StoreCms> storeCmsList = storeCmsRepository.findByUseForAndCmsTypeAndStoreid(useFor.name(),
				cmsType.name(), storeCms.getStoreid());
		if (!CollectionUtils.isEmpty(storeCmsList)) {
			return null;
		}
		storeCms.setUseFor(useFor.name());
		storeCms.setCmsType(cmsType.name());
		return storeCmsRepository.save(storeCms);
	}

	private boolean validateStoreCms(StoreCms cms) {
		return !(cms == null || StringUtils.isEmpty(cms.getStoreid()))
				&& !(cms.getEnuu() == null || StringUtils.isEmpty(cms.getEnterName()));
	}
}
